@@ -3,6 +3,8 @@ import xml.etree.ElementTree as ET
 from PIL import Image
 from collections import namedtuple
 import warnings
+import os
+import io
 
 
 class LifImage:
@@ -15,7 +17,8 @@ class LifImage:
         dims (tuple): (x, y, z, t, m)
         name (str): image name
         offsets (list): Byte position offsets for each image.
-        filename (str): The name of the LIF file being read
+        filename (str, bytes, os.PathLike, io.BufferedIOBase): The name of the LIF file
+            being read
         channels (int): Number of channels in the image
         nz (int): number of 'z' frames
         nt (int): number of 't' frames
@@ -66,45 +69,58 @@ class LifImage:
                          * self.dims.t * self.dims.m)
         if n >= seek_distance:
             raise ValueError("Invalid item trying to be retrieved.")
-        with open(self.filename, "rb") as image:
 
-            # self.offsets[1] is the length of the image
-            if self.offsets[1] == 0:
-                # In the case of a blank image, we can calculate the length from
-                # the metadata in the LIF. When this is read by the parser,
-                # it is set to zero initially.
-                image_len = seek_distance * self.dims.x * self.dims.y
-            else:
-                image_len = int(self.offsets[1] / seek_distance)
+        if isinstance(self.filename, (str, bytes, os.PathLike)):
+            image = open(self.filename, "rb")
+        elif isinstance(self.filename, io.BufferedIOBase):
+            image = self.filename
+        else:
+            raise TypeError(
+                f"expected str, bytes, os.PathLike, or io.BufferedIOBase, "
+                f"not {type(self.filename)}"
+            )
 
-            # self.offsets[0] is the offset in the file
-            image.seek(self.offsets[0] + image_len * n)
+        # self.offsets[1] is the length of the image
+        if self.offsets[1] == 0:
+            # In the case of a blank image, we can calculate the length from
+            # the metadata in the LIF. When this is read by the parser,
+            # it is set to zero initially.
+            image_len = seek_distance * self.dims.x * self.dims.y
+        else:
+            image_len = int(self.offsets[1] / seek_distance)
 
-            # It is not necessary to read from disk for truncated files
+        # self.offsets[0] is the offset in the file
+        image.seek(self.offsets[0] + image_len * n)
 
-            # Todo: Update this for 16-bit images if there is a test file
-            if self.offsets[1] == 0:
-                data = b"\00" * image_len
-            else:
-                data = image.read(image_len)
+        # It is not necessary to read from disk for truncated files
 
-            # LIF files can be either 8-bit of 16-bit.
-            # Because of how the image is read in, all of the raw
-            # data is already in 'data', we just need to tell Pillow
-            # how to set the bit depth
-            # 'L' is 8-bit, 'I;16' is 16 bit
+        # Todo: Update this for 16-bit images if there is a test file
+        if self.offsets[1] == 0:
+            data = b"\00" * image_len
+        else:
+            data = image.read(image_len)
 
-            # len(data) is the number of bytes (8-bit)
-            # However, it is safer to let the lif file tell us the resolution
-            if self.bit_depth[0] == 8:
-                return Image.frombytes("L",
-                                       (self.dims.x, self.dims.y), data)
-            elif self.bit_depth[0] <= 16:
-                return Image.frombytes("I;16",
-                                       (self.dims.x, self.dims.y), data)
-            else:
-                raise ValueError("Unknown bit-depth, please submit a bug report"
-                                 " on Github")
+        # LIF files can be either 8-bit of 16-bit.
+        # Because of how the image is read in, all of the raw
+        # data is already in 'data', we just need to tell Pillow
+        # how to set the bit depth
+        # 'L' is 8-bit, 'I;16' is 16 bit
+
+        # len(data) is the number of bytes (8-bit)
+        # However, it is safer to let the lif file tell us the resolution
+        if self.bit_depth[0] == 8:
+            read_image = Image.frombytes("L", (self.dims.x, self.dims.y), data)
+        elif self.bit_depth[0] <= 16:
+            read_image = Image.frombytes("I;16", (self.dims.x, self.dims.y), data)
+        else:
+            raise ValueError(
+                "Unknown bit-depth, please submit a bug report" " on Github"
+            )
+
+        if isinstance(self.filename, (str, bytes, os.PathLike)):
+            image.close()
+
+        return read_image
 
     def get_frame(self, z=0, t=0, c=0, m=0):
         """
@@ -288,7 +304,7 @@ def _get_len(handle):
 
 class LifFile:
     """
-    Given a path to a lif file, returns objects containing
+    Given a path or buffer to a lif file, returns objects containing
     the image and data.
 
     This is based on the java openmicroscopy bioformats lif reading code
@@ -473,7 +489,16 @@ class LifFile:
 
     def __init__(self, filename):
         self.filename = filename
-        f = open(filename, "rb")
+
+        if isinstance(filename, (str, bytes, os.PathLike)):
+            f = open(filename, "rb")
+        elif isinstance(filename, io.BufferedIOBase):
+            f = filename
+        else:
+            raise TypeError(
+                f"expected str, bytes, os.PathLike, or io.BufferedIOBase, "
+                f"not {type(filename)}"
+            )
         f_len = _get_len(f)
 
         _check_magic(f)  # read 4 byte, check for magic bytes
@@ -521,7 +546,8 @@ class LifFile:
                 else:
                     raise
 
-        f.close()
+        if isinstance(filename, (str, bytes, os.PathLike)):
+            f.close()
 
         self.image_list = self._recursive_image_find(self.xml_root)
 
